@@ -1,4 +1,4 @@
 from tapioca_arbache.tapioca_arbache import (
     PerfilClient, OauthClient, LicencaClient, JogoSelfClient, RelatorioClient,
-    JogoClient, EquipeClient
+    JogoClient, EquipeClient, MidiaClient
 )
