@@ -63,3 +63,10 @@ MIDIAS = {
         "methods": ["GET"]
     }
 }
+
+INTERFACE = {
+    "interface": {
+        "resource": "/backend/perfil/{codigo}/interface/",
+        "methods": ["GET"]
+    }
+}
